![booklab_logo](../pictures/booklab_logo.png){ width="55" align=left }
<small markdown>**BookLab System**<br>
*(c) 2023 RENware Software Systems*
</small><br><br>



# BCAT Catalog carti - manual de utilizare


***Cuprins:***

[TOC]

***

## Introducere

Acest manual descrie utilizarea functionaliatatii **"Catalog carti"** ce permite accesarea listei cartilor create in sistem si efectuarea de diverse operatii asupra acestora cum ar fi: modificare, previzualuzare, etc.

* [Navigare: `<URL general BookLab>/bcat/`](../bcat/)
* Audienta: utilizatori finali





## Desrirea ...tbd... <!--#TODO-->




<!-- -#TODO ...Under construction page... -->

![wip page](../pictures/under_maintenance.png)

UPCOMING...


